import { GraphQLResolveInfo, GraphQLSchema } from 'graphql';
import { IResolvers } from 'graphql-tools/dist/Interfaces';
import { Options } from 'graphql-binding';
import { BasePrismaOptions } from 'prisma-binding';
export interface Query {
    users: <T = User[]>(args: {
        where?: UserWhereInput;
        orderBy?: UserOrderByInput;
        skip?: Int;
        after?: String;
        before?: String;
        first?: Int;
        last?: Int;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
    user: <T = User | null>(args: {
        where: UserWhereUniqueInput;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
    usersConnection: <T = UserConnection>(args: {
        where?: UserWhereInput;
        orderBy?: UserOrderByInput;
        skip?: Int;
        after?: String;
        before?: String;
        first?: Int;
        last?: Int;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
    node: <T = Node | null>(args: {
        id: ID_Output;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
}
export interface Mutation {
    createUser: <T = User>(args: {
        data: UserCreateInput;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
    updateUser: <T = User | null>(args: {
        data: UserUpdateInput;
        where: UserWhereUniqueInput;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
    deleteUser: <T = User | null>(args: {
        where: UserWhereUniqueInput;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
    upsertUser: <T = User>(args: {
        where: UserWhereUniqueInput;
        create: UserCreateInput;
        update: UserUpdateInput;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
    updateManyUsers: <T = BatchPayload>(args: {
        data: UserUpdateInput;
        where?: UserWhereInput;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
    deleteManyUsers: <T = BatchPayload>(args: {
        where?: UserWhereInput;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<T>;
}
export interface Subscription {
    user: <T = UserSubscriptionPayload | null>(args: {
        where?: UserSubscriptionWhereInput;
    }, info?: GraphQLResolveInfo | string, options?: Options) => Promise<AsyncIterator<T>>;
}
export interface Exists {
    User: (where?: UserWhereInput) => Promise<boolean>;
}
export interface Prisma {
    query: Query;
    mutation: Mutation;
    subscription: Subscription;
    exists: Exists;
    request: <T = any>(query: string, variables?: {
        [key: string]: any;
    }) => Promise<T>;
    delegate(operation: 'query' | 'mutation', fieldName: string, args: {
        [key: string]: any;
    }, infoOrQuery?: GraphQLResolveInfo | string, options?: Options): Promise<any>;
    delegateSubscription(fieldName: string, args?: {
        [key: string]: any;
    }, infoOrQuery?: GraphQLResolveInfo | string, options?: Options): Promise<AsyncIterator<any>>;
    getAbstractResolvers(filterSchema?: GraphQLSchema | string): IResolvers;
}
export interface BindingConstructor<T> {
    new (options: BasePrismaOptions): T;
}
export declare const Prisma: BindingConstructor<Prisma>;
/**
 * Types
 */
export declare type UserOrderByInput = 'id_ASC' | 'id_DESC' | 'email_ASC' | 'email_DESC' | 'password_ASC' | 'password_DESC' | 'name_ASC' | 'name_DESC' | 'inviteToken_ASC' | 'inviteToken_DESC' | 'inviteAccepted_ASC' | 'inviteAccepted_DESC' | 'emailConfirmed_ASC' | 'emailConfirmed_DESC' | 'emailConfirmToken_ASC' | 'emailConfirmToken_DESC' | 'resetToken_ASC' | 'resetToken_DESC' | 'resetExpires_ASC' | 'resetExpires_DESC' | 'deletedAt_ASC' | 'deletedAt_DESC' | 'lastLogin_ASC' | 'lastLogin_DESC' | 'joinedAt_ASC' | 'joinedAt_DESC' | 'isSuper_ASC' | 'isSuper_DESC' | 'updatedAt_ASC' | 'updatedAt_DESC' | 'createdAt_ASC' | 'createdAt_DESC';
export declare type MutationType = 'CREATED' | 'UPDATED' | 'DELETED';
export interface UserWhereUniqueInput {
    id?: ID_Input;
    email?: String;
}
export interface UserCreateInput {
    email: String;
    password: String;
    name: String;
    inviteToken?: String;
    inviteAccepted?: Boolean;
    emailConfirmed?: Boolean;
    emailConfirmToken?: String;
    resetToken?: String;
    resetExpires?: DateTime;
    deletedAt?: DateTime;
    lastLogin?: DateTime;
    joinedAt: DateTime;
    isSuper?: Boolean;
}
export interface UserUpdateInput {
    email?: String;
    password?: String;
    name?: String;
    inviteToken?: String;
    inviteAccepted?: Boolean;
    emailConfirmed?: Boolean;
    emailConfirmToken?: String;
    resetToken?: String;
    resetExpires?: DateTime;
    deletedAt?: DateTime;
    lastLogin?: DateTime;
    joinedAt?: DateTime;
    isSuper?: Boolean;
}
export interface UserSubscriptionWhereInput {
    AND?: UserSubscriptionWhereInput[] | UserSubscriptionWhereInput;
    OR?: UserSubscriptionWhereInput[] | UserSubscriptionWhereInput;
    NOT?: UserSubscriptionWhereInput[] | UserSubscriptionWhereInput;
    mutation_in?: MutationType[] | MutationType;
    updatedFields_contains?: String;
    updatedFields_contains_every?: String[] | String;
    updatedFields_contains_some?: String[] | String;
    node?: UserWhereInput;
}
export interface UserWhereInput {
    AND?: UserWhereInput[] | UserWhereInput;
    OR?: UserWhereInput[] | UserWhereInput;
    NOT?: UserWhereInput[] | UserWhereInput;
    id?: ID_Input;
    id_not?: ID_Input;
    id_in?: ID_Input[] | ID_Input;
    id_not_in?: ID_Input[] | ID_Input;
    id_lt?: ID_Input;
    id_lte?: ID_Input;
    id_gt?: ID_Input;
    id_gte?: ID_Input;
    id_contains?: ID_Input;
    id_not_contains?: ID_Input;
    id_starts_with?: ID_Input;
    id_not_starts_with?: ID_Input;
    id_ends_with?: ID_Input;
    id_not_ends_with?: ID_Input;
    email?: String;
    email_not?: String;
    email_in?: String[] | String;
    email_not_in?: String[] | String;
    email_lt?: String;
    email_lte?: String;
    email_gt?: String;
    email_gte?: String;
    email_contains?: String;
    email_not_contains?: String;
    email_starts_with?: String;
    email_not_starts_with?: String;
    email_ends_with?: String;
    email_not_ends_with?: String;
    password?: String;
    password_not?: String;
    password_in?: String[] | String;
    password_not_in?: String[] | String;
    password_lt?: String;
    password_lte?: String;
    password_gt?: String;
    password_gte?: String;
    password_contains?: String;
    password_not_contains?: String;
    password_starts_with?: String;
    password_not_starts_with?: String;
    password_ends_with?: String;
    password_not_ends_with?: String;
    name?: String;
    name_not?: String;
    name_in?: String[] | String;
    name_not_in?: String[] | String;
    name_lt?: String;
    name_lte?: String;
    name_gt?: String;
    name_gte?: String;
    name_contains?: String;
    name_not_contains?: String;
    name_starts_with?: String;
    name_not_starts_with?: String;
    name_ends_with?: String;
    name_not_ends_with?: String;
    inviteToken?: String;
    inviteToken_not?: String;
    inviteToken_in?: String[] | String;
    inviteToken_not_in?: String[] | String;
    inviteToken_lt?: String;
    inviteToken_lte?: String;
    inviteToken_gt?: String;
    inviteToken_gte?: String;
    inviteToken_contains?: String;
    inviteToken_not_contains?: String;
    inviteToken_starts_with?: String;
    inviteToken_not_starts_with?: String;
    inviteToken_ends_with?: String;
    inviteToken_not_ends_with?: String;
    inviteAccepted?: Boolean;
    inviteAccepted_not?: Boolean;
    emailConfirmed?: Boolean;
    emailConfirmed_not?: Boolean;
    emailConfirmToken?: String;
    emailConfirmToken_not?: String;
    emailConfirmToken_in?: String[] | String;
    emailConfirmToken_not_in?: String[] | String;
    emailConfirmToken_lt?: String;
    emailConfirmToken_lte?: String;
    emailConfirmToken_gt?: String;
    emailConfirmToken_gte?: String;
    emailConfirmToken_contains?: String;
    emailConfirmToken_not_contains?: String;
    emailConfirmToken_starts_with?: String;
    emailConfirmToken_not_starts_with?: String;
    emailConfirmToken_ends_with?: String;
    emailConfirmToken_not_ends_with?: String;
    resetToken?: String;
    resetToken_not?: String;
    resetToken_in?: String[] | String;
    resetToken_not_in?: String[] | String;
    resetToken_lt?: String;
    resetToken_lte?: String;
    resetToken_gt?: String;
    resetToken_gte?: String;
    resetToken_contains?: String;
    resetToken_not_contains?: String;
    resetToken_starts_with?: String;
    resetToken_not_starts_with?: String;
    resetToken_ends_with?: String;
    resetToken_not_ends_with?: String;
    resetExpires?: DateTime;
    resetExpires_not?: DateTime;
    resetExpires_in?: DateTime[] | DateTime;
    resetExpires_not_in?: DateTime[] | DateTime;
    resetExpires_lt?: DateTime;
    resetExpires_lte?: DateTime;
    resetExpires_gt?: DateTime;
    resetExpires_gte?: DateTime;
    deletedAt?: DateTime;
    deletedAt_not?: DateTime;
    deletedAt_in?: DateTime[] | DateTime;
    deletedAt_not_in?: DateTime[] | DateTime;
    deletedAt_lt?: DateTime;
    deletedAt_lte?: DateTime;
    deletedAt_gt?: DateTime;
    deletedAt_gte?: DateTime;
    lastLogin?: DateTime;
    lastLogin_not?: DateTime;
    lastLogin_in?: DateTime[] | DateTime;
    lastLogin_not_in?: DateTime[] | DateTime;
    lastLogin_lt?: DateTime;
    lastLogin_lte?: DateTime;
    lastLogin_gt?: DateTime;
    lastLogin_gte?: DateTime;
    joinedAt?: DateTime;
    joinedAt_not?: DateTime;
    joinedAt_in?: DateTime[] | DateTime;
    joinedAt_not_in?: DateTime[] | DateTime;
    joinedAt_lt?: DateTime;
    joinedAt_lte?: DateTime;
    joinedAt_gt?: DateTime;
    joinedAt_gte?: DateTime;
    isSuper?: Boolean;
    isSuper_not?: Boolean;
}
export interface Node {
    id: ID_Output;
}
export interface PageInfo {
    hasNextPage: Boolean;
    hasPreviousPage: Boolean;
    startCursor?: String;
    endCursor?: String;
}
export interface UserPreviousValues {
    id: ID_Output;
    email: String;
    password: String;
    name: String;
    inviteToken?: String;
    inviteAccepted: Boolean;
    emailConfirmed: Boolean;
    emailConfirmToken?: String;
    resetToken?: String;
    resetExpires?: DateTime;
    deletedAt?: DateTime;
    lastLogin?: DateTime;
    joinedAt: DateTime;
    isSuper: Boolean;
}
export interface User extends Node {
    id: ID_Output;
    email: String;
    password: String;
    name: String;
    inviteToken?: String;
    inviteAccepted: Boolean;
    emailConfirmed: Boolean;
    emailConfirmToken?: String;
    resetToken?: String;
    resetExpires?: DateTime;
    deletedAt?: DateTime;
    lastLogin?: DateTime;
    joinedAt: DateTime;
    isSuper: Boolean;
}
export interface UserEdge {
    node: User;
    cursor: String;
}
export interface UserConnection {
    pageInfo: PageInfo;
    edges: UserEdge[];
    aggregate: AggregateUser;
}
export interface UserSubscriptionPayload {
    mutation: MutationType;
    node?: User;
    updatedFields?: String[];
    previousValues?: UserPreviousValues;
}
export interface AggregateUser {
    count: Int;
}
export interface BatchPayload {
    count: Long;
}
export declare type DateTime = Date | string;
export declare type ID_Input = string | number;
export declare type ID_Output = string;
export declare type Int = number;
export declare type String = string;
export declare type Boolean = boolean;
export declare type Long = string;
